Renamed burst_sink_qa/burst_source_qa to burst_sink/burst_source
diff --git a/include/grgsm/qa_utils/CMakeLists.txt b/include/grgsm/qa_utils/CMakeLists.txt
index e0b5579..44bbbfb 100644
--- a/include/grgsm/qa_utils/CMakeLists.txt
+++ b/include/grgsm/qa_utils/CMakeLists.txt
@@ -21,8 +21,8 @@
 # Install public header files
 ########################################################################
 install(FILES
-    burst_sink_qa.h
-    burst_source_qa.h
+    burst_sink.h
+    burst_source.h
     message_source.h
     message_sink.h DESTINATION include/grgsm/qa_utils
 )
diff --git a/include/grgsm/qa_utils/burst_sink_qa.h b/include/grgsm/qa_utils/burst_sink.h
similarity index 81%
rename from include/grgsm/qa_utils/burst_sink_qa.h
rename to include/grgsm/qa_utils/burst_sink.h
index 3b5cac2..266cbc8 100644
--- a/include/grgsm/qa_utils/burst_sink_qa.h
+++ b/include/grgsm/qa_utils/burst_sink.h
@@ -20,8 +20,8 @@
  *
  */
 
-#ifndef INCLUDED_GSM_BURST_SINK_QA_H
-#define INCLUDED_GSM_BURST_SINK_QA_H
+#ifndef INCLUDED_GSM_BURST_SINK_H
+#define INCLUDED_GSM_BURST_SINK_H
 
 #include <grgsm/api.h>
 #include <gnuradio/block.h>
@@ -34,17 +34,17 @@
      * \ingroup gsm
      *
      */
-    class GSM_API burst_sink_qa : virtual public gr::block
+    class GSM_API burst_sink : virtual public gr::block
     {
      public:
-      typedef boost::shared_ptr<burst_sink_qa> sptr;
+      typedef boost::shared_ptr<burst_sink> sptr;
 
       /*!
        * \brief Return a shared_ptr to a new instance of grgsm::burst_sink_qa.
        *
        * To avoid accidental use of raw pointers, grgsm::burst_sink_qa's
        * constructor is in a private implementation
        * class. grgsm::burst_sink_qa::make is the public interface for
        * creating new instances.
        */
       static sptr make();
@@ -56,5 +56,5 @@
   } // namespace gsm
 } // namespace gr
 
-#endif /* INCLUDED_GSM_BURST_SINK_QA_H */
+#endif /* INCLUDED_GSM_BURST_SINK_H */
 
@@ -34,17 +34,17 @@
 
       /*!
-       * \brief Return a shared_ptr to a new instance of grgsm::burst_sink_qa.
+       * \brief Return a shared_ptr to a new instance of grgsm::burst_sink.
        *
@@ -34,17 +34,17 @@
        *
-       * To avoid accidental use of raw pointers, grgsm::burst_sink_qa's
+       * To avoid accidental use of raw pointers, grgsm::burst_sink's
        * constructor is in a private implementation
@@ -34,17 +34,17 @@
        * constructor is in a private implementation
-       * class. grgsm::burst_sink_qa::make is the public interface for
+       * class. grgsm::burst_sink::make is the public interface for
        * creating new instances.
        */
diff --git a/include/grgsm/qa_utils/burst_source_qa.h b/include/grgsm/qa_utils/burst_source.h
similarity index 82%
rename from include/grgsm/qa_utils/burst_source_qa.h
rename to include/grgsm/qa_utils/burst_source.h
index c3c5713..bfed70f 100644
--- a/include/grgsm/qa_utils/burst_source_qa.h
+++ b/include/grgsm/qa_utils/burst_source.h
@@ -20,8 +20,8 @@
  *
  */
 
-#ifndef INCLUDED_GSM_BURST_SOURCE_QA_H
-#define INCLUDED_GSM_BURST_SOURCE_QA_H
+#ifndef INCLUDED_GSM_BURST_SOURCE_H
+#define INCLUDED_GSM_BURST_SOURCE_H
 
 #include <grgsm/api.h>
 #include <gnuradio/block.h>
@@ -34,17 +34,17 @@
      * \ingroup gsm
      *
      */
-    class GSM_API burst_source_qa : virtual public gr::block
+    class GSM_API burst_source : virtual public gr::block
     {
      public:
-      typedef boost::shared_ptr<burst_source_qa> sptr;
+      typedef boost::shared_ptr<burst_source> sptr;
 
       /*!
        * \brief Return a shared_ptr to a new instance of grgsm::burst_source_qa.
        *
        * To avoid accidental use of raw pointers, grgsm::burst_source_qa's
        * constructor is in a private implementation
        * class. grgsm::burst_source_qa::make is the public interface for
        * creating new instances.
        */
       static sptr make(const std::vector<int> &framenumbers,
@@ -59,6 +59,6 @@
   } // namespace gsm
 } // namespace gr
 
-#endif /* INCLUDED_GSM_BURST_SOURCE_QA_H */
+#endif /* INCLUDED_GSM_BURST_SOURCE_H */
@@ -34,17 +34,17 @@
 
       /*!
-       * \brief Return a shared_ptr to a new instance of grgsm::burst_source_qa.
+       * \brief Return a shared_ptr to a new instance of grgsm::burst_source.
        *
@@ -34,17 +34,17 @@
        *
-       * To avoid accidental use of raw pointers, grgsm::burst_source_qa's
+       * To avoid accidental use of raw pointers, grgsm::burst_source's
        * constructor is in a private implementation
@@ -34,17 +34,17 @@
        * constructor is in a private implementation
-       * class. grgsm::burst_source_qa::make is the public interface for
+       * class. grgsm::burst_source::make is the public interface for
        * creating new instances.
        */